# AlgoMart

Collection of algorithms in python

### Sorting Algorithm

- Bubble Sort - `bubble_sort`
- Insertion Sort - `insertion_sort`
- Selection Sort - `selection_sort`
- Quick Sort - `quick_sort`
- Merge Sort - `merge_sort`
- Heap Sort - `heap_sort`
- Counting Sort - `counting_sort`
- Radix Sort - `radix_sort`


Sample Code

```python
from algomart.algorithm.sort import bubble_sort

print(bubble_sort([3, 2, 1]))
```
